from rich import print
from rich.markdown import Markdown

from changelogger import changelog
from changelogger.exceptions import CommandException
from changelogger.models.domain_models import VersionInfo


def content(
    version: str,
    pretty: bool = True,
) -> None:
    version_info = VersionInfo.parse(version)
    """Retrieves the changelog content for the specified version."""
    all_versions = changelog.get_all_versions()
    if version_info not in all_versions:
        raise CommandException(f"Could not find version {version}.")

    i = all_versions.index(version_info)
    prev_version = all_versions[i + 1] if i + 1 < len(all_versions) else None
    release_notes = changelog.get_release_notes(version_info, prev_version)

    md = release_notes.markdown()
    if pretty:
        print(Markdown(md))
    else:
        print(md)



from pathlib import Path

import typer
from git.exc import InvalidGitRepositoryError
from git.repo import Repo
from rich import print

from changelogger.app._commands.init import init
from changelogger.app.manage import app as manage_app
from changelogger.app.unreleased import app as unrealeased_app
from changelogger.conf import settings

app = typer.Typer()
app.add_typer(manage_app)
app.add_typer(unrealeased_app)

app.command()(init)


def version_callback(value: bool):
    if value:
        print(settings.CHANGELOGGER_VERSION)
        raise typer.Exit()


@app.callback()
def changelogger(
    ctx: typer.Context,
    _: bool = typer.Option(
        False,
        "-v",
        "--version",
        help="The version of Changelogger you have installed.",
        callback=version_callback,
    ),
):
    if (
        not ctx.invoked_subcommand == init.__name__
        and not settings.CHANGELOG_PATH.exists()
    ):
        print(
            "[bold red]Error: [/bold red]"
            f"Could not find changelog file [bold]{settings.CHANGELOG_PATH}[/bold]."
        )
        raise typer.Abort()

    if settings.HAS_DEFAULTS:
        try:
            __ = Repo(Path.cwd()).git_dir
        except InvalidGitRepositoryError:
            print(
                "[bold red]Error: [/bold red]"
                "Must be in a git repo to use the default behavior."
            )
            raise typer.Abort()


changelogger.__doc__ = f"""
{settings.CHANGELOGGER_DESCRIPTION}\n
version: {settings.CHANGELOGGER_VERSION}
"""



import typer

from changelogger.app.manage._commands.check import check
from changelogger.app.manage._commands.content import content
from changelogger.app.manage._commands.upgrade import upgrade
from changelogger.app.manage._commands.versions import versions

app = typer.Typer()
app.command()(upgrade)
app.command()(check)
app.command()(content)
app.command()(versions)


@app.callback()
def manage():
    """Management commands for changelog and other versioned files,
    as specified in the changelogger config file.
    """



from rich import print
from typer import Option

from changelogger import changelog


def versions(
    latest: bool = Option(
        False, help="Gets the latest version in the changelog file"
    ),
    show_all: bool = Option(False, help="Get all versions."),
    num_versions: int = Option(10, help="The number of versions to get."),
) -> None:
    """Retrieves the versions found in the changelog file."""
    if latest:
        print(changelog.get_latest_version())
        return

    all_versions = changelog.get_all_versions()
    end = len(all_versions) if show_all else num_versions
    print("\n".join(map(str, all_versions[:end])))
